summaryrefslogtreecommitdiffstats
path: root/kcontrol/keys/treeview.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:10:07 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:10:07 +0000
commitfd3a982e26813f5bcc82c7e89ce6fa2ad44432bf (patch)
tree9eda848e56fcb862fdfdf479adeccd95b6fe387a /kcontrol/keys/treeview.cpp
parent02f67d0e1355b79b1806746efb0f2f640e57f13d (diff)
downloadtdebase-fd3a982e26813f5bcc82c7e89ce6fa2ad44432bf.tar.gz
tdebase-fd3a982e26813f5bcc82c7e89ce6fa2ad44432bf.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1212480 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kcontrol/keys/treeview.cpp')
-rw-r--r--kcontrol/keys/treeview.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kcontrol/keys/treeview.cpp b/kcontrol/keys/treeview.cpp
index 0d1ddc3cc..58de8a1f5 100644
--- a/kcontrol/keys/treeview.cpp
+++ b/kcontrol/keys/treeview.cpp
@@ -156,8 +156,8 @@ void AppTreeView::fillBranch(const TQString& rPath, AppTreeItem *parent)
TQString groupCaption = g->caption();
// Item names may contain ampersands. To avoid them being converted
- // to accelerators, tqreplace them with two ampersands.
- groupCaption.tqreplace("&", "&&");
+ // to accelerators, replace them with two ampersands.
+ groupCaption.replace("&", "&&");
AppTreeItem *item;
if (parent == 0)
@@ -177,8 +177,8 @@ void AppTreeView::fillBranch(const TQString& rPath, AppTreeItem *parent)
TQString serviceCaption = s->name();
// Item names may contain ampersands. To avoid them being converted
- // to accelerators, tqreplace them with two ampersands.
- serviceCaption.tqreplace("&", "&&");
+ // to accelerators, replace them with two ampersands.
+ serviceCaption.replace("&", "&&");
AppTreeItem* item;
if (parent == 0)
@@ -228,7 +228,7 @@ TQStringList AppTreeView::fileList(const TQString& rPath)
TQStringList files = dir.entryList();
for (TQStringList::ConstIterator it = files.begin(); it != files.end(); ++it) {
// does not work?!
- //if (filelist.tqcontains(*it)) continue;
+ //if (filelist.contains(*it)) continue;
if (relativePath.isEmpty()) {
filelist.remove(*it); // hack
@@ -266,7 +266,7 @@ TQStringList AppTreeView::dirList(const TQString& rPath)
for (TQStringList::ConstIterator it = subdirs.begin(); it != subdirs.end(); ++it) {
if ((*it) == "." || (*it) == "..") continue;
// does not work?!
- // if (dirlist.tqcontains(*it)) continue;
+ // if (dirlist.contains(*it)) continue;
if (relativePath.isEmpty()) {
dirlist.remove(*it); //hack